@@ -7,7 +7,6 @@ package Debian::Debhelper::Buildsystem::gradle;
 
 use strict;
 use base 'Debian::Debhelper::Buildsystem';
-use Debian::Debhelper::Dh_Lib qw(%dh doit);
 
 sub DESCRIPTION {
 	"Gradle (build.gradle)"
@@ -30,19 +29,28 @@ sub new {
 		"--no-daemon",
 		"--refresh-dependencies",
 		"--gradle-user-home", ".gradle",
+		"-Duser.home=.",
+		"-Duser.name=debian",
 	#	"--init-script", "/usr/share/gradle-debian-helper/init.gradle",
-		);
-	
-	# Copy the init script under .gradle/init.d to work around a bug with the --init-script parameter (GRADLE-3197)
-	$this->doit_in_builddir("mkdir", "-p", ".gradle/init.d");
-	$this->doit_in_builddir("cp", "/usr/share/gradle-debian-helper/init.gradle", ".gradle/init.d/");
-	
+		);	
+
+	my $numthreads = $this->get_parallel();
+	if ($numthreads == -1) {
+		push(@{$this->{gradle_cmd}}, "--parallel");
+	} elsif ($numthreads > 1) {
+		push(@{$this->{gradle_cmd}}, "--parallel", "--max-workers=$numthreads");
+	}
+
 	return $this;
 }
 
 sub build {
 	my $this=shift;
 
+	# Copy the init script under .gradle/init.d to work around a bug with the --init-script parameter (GRADLE-3197)
+	$this->doit_in_builddir("mkdir", "-p", ".gradle/init.d");
+	$this->doit_in_builddir("cp", "/usr/share/gradle-debian-helper/init.gradle", ".gradle/init.d/");
+	
 	if (!@_) {
 		push(@_, "jar");
 	}
@@ -53,8 +61,9 @@ sub build {
 sub clean {
 	my $this=shift;
 
-	doit(@{$this->{gradle_cmd}}, "clean");
-	doit("rm", "-Rf", "$this->{cwd}/.gradle");
+	$this->doit_in_builddir("find . -wholename .*build/tmp | xargs echo | sed -e 's^build/tmp^build^g' | xargs rm -Rf");
+	$this->doit_in_builddir("find . -wholename .*build/debian | xargs echo | sed -e 's^build/tmp^build^g' | xargs rm -Rf");
+	$this->doit_in_builddir("rm", "-Rf", "$this->{cwd}/.gradle", "$this->{cwd}/buildSrc/.gradle", ".m2");
 }
 
 1
